@@ -4,7 +4,6 @@ from logging import getLogger
 
 from wx import DC
 
-from miniogl.Shape import Shape
 from ogl.OglAssociation import OglAssociation
 
 
@@ -32,24 +31,16 @@ class OglAggregation(OglAssociation):
 
     def Draw(self, dc: DC, withChildren: bool = False):
         """
-        Called for contents drawing of links.
-
-        @param  dc : Device context
-        @param withChildren
-
-        @since 1.0
-        @author Philippe Waelti <pwaelti@eivd.ch>
+        Called to draw link contents
+        Args:
+            dc:     The device context
+            withChildren:  Should we draw children
         """
         super().Draw(dc, withChildren)
 
-        # Draw losange
-        self.drawLosange(dc, False)
+        # Draw diamond
+        self.drawDiamond(dc, False)
 
     def __repr__(self):
-
-        srcShape:  Shape = self.getSourceShape()
-        destShape: Shape = self.getDestinationShape()
-        sourceId:  int   = srcShape.GetID()
-        destId:    int   = destShape.GetID()
-
-        return f'OglAggregation - from: id: {sourceId} {self.getSourceShape()} to: id: {destId} {self.getDestinationShape()}'
+        from ogl.OglLink import OglLink
+        return f'OglAggregation - {OglLink.__repr__(self)}'
