@@ -54,6 +54,7 @@ from ogl.preferences.OglPreferences import OglPreferences
 
 MARGIN: int = 10
 
+
 @dataclass
 class ClickedOnSelectAnchorPointData:
     clicked:           bool             = False
@@ -209,9 +210,9 @@ class OglClass(OglObject):
         self.SetSize(w, h)
 
         # to automatically replace the sizer objects at a correct place
-        if self.IsSelected():
-            self.SetSelected(False)
-            self.SetSelected(True)
+        if self.selected is True:
+            self.selected = False
+            self.selected = True
 
     def OnRightDown(self, event: MouseEvent):
         """
@@ -365,7 +366,7 @@ class OglClass(OglObject):
         else:
             assert False, 'Unknown display type'
 
-    def _drawClassHeader(self, dc, draw=False, initialX=None, initialY=None, calcWidth=False):
+    def _drawClassHeader(self, dc: DC, draw: bool = False, initialX=None, initialY=None, calcWidth: bool = False):
         """
         Calculate the class header position and size and display it if
         a draw is True
@@ -400,9 +401,9 @@ class OglClass(OglObject):
         h += lth
 
         # draw a pyutClass name
-        name = self.pyutObject.name
+        name: str = self.pyutObject.name
         dc.SetFont(self._nameFont)
-        nameWidth = self.GetTextWidth(dc, name)
+        nameWidth: int = self.GetTextWidth(dc, name)
         if draw:
             dc.DrawText(name, x + (w - nameWidth) // 2, y + h)
         if calcWidth:
@@ -410,20 +411,24 @@ class OglClass(OglObject):
         dc.SetFont(self._defaultFont)
         h += self.GetTextHeight(dc, str(name))
         h += lth
-
-        # draw the stereotype if there's one
+        #
+        # Draw the stereotype value
+        #
         pyutClass: PyutClass = self.pyutObject
-        # stereo = self.getPyutObject().getStereotype()
         stereo: PyutStereotype = pyutClass.stereotype
-        if stereo is not None and stereo.name != '' and pyutClass.displayStereoType is True:
-            name = str(stereo)
-            nameWidth = self.GetTextWidth(dc, name)
-            if draw:
-                dc.DrawText(name, x + (w - nameWidth) // 2, y + h)
-            if calcWidth:
-                w = max(nameWidth, w)
-            h += self.GetTextHeight(dc, str(name))
-            h += lth
+
+        if pyutClass.displayStereoType is True and stereo is not None and stereo != PyutStereotype.NO_STEREOTYPE:
+            stereoTypeValue: str = f'<<{stereo.value}>>'
+        else:
+            stereoTypeValue = ''
+
+        stereoTypeValueWidth = self.GetTextWidth(dc, stereoTypeValue)
+        if draw:
+            dc.DrawText(stereoTypeValue, x + (w - stereoTypeValueWidth) // 2, y + h)
+        if calcWidth:
+            w = max(stereoTypeValueWidth, w)
+        h += self.GetTextHeight(dc, str(stereoTypeValue))
+        h += lth
 
         # Return sizes
         return x, y, w, h
