@@ -10,7 +10,7 @@ from wx import FONTWEIGHT_NORMAL
 from wx import Font
 
 from miniogl.Common import Common
-from miniogl.AttachmentLocation import AttachmentLocation
+from miniogl.AttachmentSide import AttachmentSide
 from miniogl.SelectAnchorPoint import SelectAnchorPoint
 from miniogl.LollipopLine import LollipopLine
 
@@ -154,26 +154,26 @@ class OglInterface2(LollipopLine, Common):
     def _determineInterfaceNamePosition(self, destinationAnchor: SelectAnchorPoint, pixelSize: Tuple[int, int], textSize: Tuple[int, int]) -> OglPosition:
 
         oglPosition:     OglPosition     = OglPosition()
-        attachmentPoint: AttachmentLocation = destinationAnchor.attachmentPoint
+        attachmentPoint: AttachmentSide = destinationAnchor.attachmentPoint
 
         x, y = destinationAnchor.GetPosition()
 
         fWidth, fHeight = pixelSize
         tWidth, tHeight = textSize
 
-        if attachmentPoint == AttachmentLocation.NORTH:
+        if attachmentPoint == AttachmentSide.NORTH:
             y -= (LollipopLine.LOLLIPOP_LINE_LENGTH + (LollipopLine.LOLLIPOP_CIRCLE_RADIUS * 2) + OglInterface2.ADJUST_AWAY_FROM_IMPLEMENTOR)
             x -= (tWidth // 2)
             oglPosition.x = x
             oglPosition.y = y
 
-        elif attachmentPoint == AttachmentLocation.SOUTH:
+        elif attachmentPoint == AttachmentSide.SOUTH:
             y += (LollipopLine.LOLLIPOP_LINE_LENGTH + LollipopLine.LOLLIPOP_CIRCLE_RADIUS + OglInterface2.ADJUST_AWAY_FROM_IMPLEMENTOR)
             x -= (tWidth // 2)
             oglPosition.x = x
             oglPosition.y = y
 
-        elif attachmentPoint == AttachmentLocation.WEST:
+        elif attachmentPoint == AttachmentSide.WEST:
             y = y - (fHeight * 2)
             originalX: int = x
             x = x - LollipopLine.LOLLIPOP_LINE_LENGTH - (tWidth // 2)
@@ -182,7 +182,7 @@ class OglInterface2(LollipopLine, Common):
             oglPosition.x = x
             oglPosition.y = y
 
-        elif attachmentPoint == AttachmentLocation.EAST:
+        elif attachmentPoint == AttachmentSide.EAST:
             y = y - (fHeight * 2)
             x = x + round(LollipopLine.LOLLIPOP_LINE_LENGTH * 0.8)
             oglPosition.x = x
