@@ -7,7 +7,6 @@ from logging import getLogger
 
 from math import sqrt
 
-# noinspection PyPackageRequirements
 from deprecated import deprecated
 
 from wx import BLACK_PEN
@@ -19,18 +18,19 @@ from wx import MenuItem
 from wx import MouseEvent
 
 
+from pyutmodel.PyutLink import PyutLink
+from pyutmodel.PyutLink import PyutLinks
+
 from miniogl.AnchorPoint import AnchorPoint
 from miniogl.ControlPoint import ControlPoint
 from miniogl.LinePoint import LinePoint
 from miniogl.LineShape import LineShape
 from miniogl.Shape import Shape
 from miniogl.ShapeEventHandler import ShapeEventHandler
-from miniogl.AttachmentLocation import AttachmentLocation
+from miniogl.AttachmentSide import AttachmentSide
 
 from ogl.OglPosition import OglPosition
 
-from pyutmodel.PyutLink import PyutLink
-
 from ogl.IllegalOperationException import IllegalOperationException
 
 from ogl.OglUtils import OglUtils
@@ -83,21 +83,21 @@ class OglLink(LineShape, ShapeEventHandler):
 
             sw, sh = self._srcShape.GetSize()
             dw, dh = self._destShape.GetSize()
-            if orient == AttachmentLocation.NORTH:
+            if orient == AttachmentSide.NORTH:
                 srcX, srcY = sw//2, 0
                 dstX, dstY = dw//2, dh
-            elif orient == AttachmentLocation.SOUTH:
+            elif orient == AttachmentSide.SOUTH:
                 srcX, srcY = sw//2, sh
                 dstX, dstY = dw//2, 0
-            elif orient == AttachmentLocation.EAST:
+            elif orient == AttachmentSide.EAST:
                 srcX, srcY = sw, sh//2
                 dstX, dstY = 0, dh//2
-            elif orient == AttachmentLocation.WEST:
+            elif orient == AttachmentSide.WEST:
                 srcX, srcY = 0, sh//2
                 dstX, dstY = dw, dh//2
 
             # ============== Avoid over-lining; Added by C.Dutoit ================
-            # lstAnchorsPoints = [anchor.GetRelativePosition() for anchor in srcShape.GetAnchors()]
+            # lstAnchorsPoints = [anchor.GetRelativePosition() for anchor in srcSDInstance.GetAnchors()]
             # while (srcX, srcY) in lstAnchorsPoints:
             #     OglLink.clsLogger.warning(f'Over-lining in source shape')
             #     if orient == PyutAttachmentPoint.NORTH or orient == PyutAttachmentPoint.SOUTH:
@@ -105,11 +105,11 @@ class OglLink(LineShape, ShapeEventHandler):
             #     else:
             #         srcY += 10
             #
-            # lstAnchorsPoints = [anchor.GetRelativePosition() for anchor in dstShape.GetAnchors()]
+            # lstAnchorsPoints = [anchor.GetRelativePosition() for anchor in dstSDInstance.GetAnchors()]
             # while (dstX, dstY) in lstAnchorsPoints:
             #     from org.pyut.ogl.OglClass import OglClass
-            #     dstShape: OglClass = cast(OglClass, dstShape)
-            #     OglLink.clsLogger.warning(f'Over-lining in destination shape: {dstShape.getPyutObject}')
+            #     dstSDInstance: OglClass = cast(OglClass, dstSDInstance)
+            #     OglLink.clsLogger.warning(f'Over-lining in destination shape: {dstSDInstance.getPyutObject}')
             #     if orient == PyutAttachmentPoint.NORTH or orient == PyutAttachmentPoint.SOUTH:
             #         dstX += 10
             #     else:
@@ -128,8 +128,8 @@ class OglLink(LineShape, ShapeEventHandler):
         srcAnchor.SetVisible(False)
         dstAnchor.SetVisible(False)
         OglLink.clsLogger.debug(f'src anchor pos: {srcAnchor.GetPosition()} dst anchor pos {dstAnchor.GetPosition()}')
-        srcAnchor.SetDraggable(True)
-        dstAnchor.SetDraggable(True)
+        srcAnchor.draggable = True
+        dstAnchor.draggable = True
         # Init
         LineShape.__init__(self, srcAnchor, dstAnchor)
         # Set up painting colors
@@ -142,7 +142,7 @@ class OglLink(LineShape, ShapeEventHandler):
             self._link = PyutLink()
 
     @staticmethod
-    def getOrient(srcX, srcY, destX, destY) -> AttachmentLocation:
+    def getOrient(srcX, srcY, destX, destY) -> AttachmentSide:
         """
         Giving a source and destination, returns where the destination
         is located according to the source.
@@ -156,25 +156,42 @@ class OglLink(LineShape, ShapeEventHandler):
         deltaY = srcY - destY
         if deltaX > 0:  # dest is not east
             if deltaX > abs(deltaY):  # dest is west
-                return AttachmentLocation.WEST
+                return AttachmentSide.WEST
             elif deltaY > 0:
-                return AttachmentLocation.NORTH
+                return AttachmentSide.NORTH
             else:
-                return AttachmentLocation.SOUTH
+                return AttachmentSide.SOUTH
         else:  # dest is not west
             if -deltaX > abs(deltaY):  # dest is east
-                return AttachmentLocation.EAST
+                return AttachmentSide.EAST
             elif deltaY > 0:
-                return AttachmentLocation.NORTH
+                return AttachmentSide.NORTH
             else:
-                return AttachmentLocation.SOUTH
+                return AttachmentSide.SOUTH
 
+    @property
+    def sourceShape(self):
+        """
+        Returns:  the source shape for this link.
+        """
+        return self._srcShape
+
+    @property
+    def destinationShape(self):
+        """
+
+        Returns:    The destination shape for this link.
+        """
+        return self._destShape
+
+    @deprecated(reason='Use sourceShape property')
     def getSourceShape(self):
         """
         Returns:  the source shape for this link.
         """
         return self._srcShape
 
+    @deprecated(reason='Use destinationShape property')
     def getDestinationShape(self):
         """
 
@@ -223,26 +240,58 @@ class OglLink(LineShape, ShapeEventHandler):
             self._dstAnchor.SetProtected(False)
             self._srcAnchor.Detach()
             self._dstAnchor.Detach()
-            try:
-                self.getSourceShape().links.remove(self)
-            except ValueError:
-                pass
-            try:
-                self.getDestinationShape().links.remove(self)
-            except ValueError:
-                pass
-            try:
-                self._link.getSource().links.remove(self._link)
-            except ValueError:
-                pass        # TODO:  Fix this silent failure
+            self._detachFromOglEnds()
+            self._detachModel()
+
+    def _detachModel(self):
+        """
+        From the data model of the source remove the
+        data model link
+        """
+        from typing import Union
+        from pyutmodel.PyutClass import PyutClass
+        from pyutmodel.PyutNote import PyutNote
+        try:
+            # self._link.getSource().links.remove(self._link)
+            pyutSrc: Union[PyutClass, PyutNote] = self._link.getSource()
+            links: PyutLinks = pyutSrc.links
+            links.remove(self._link)
+        except ValueError as ve:
+            self.clsLogger.warning(f'Ignoring source removal error: {ve}')
+
+    def _detachFromOglEnds(self):
+        """
+        Remove us (self) from the links list in each of the ends
+
+        """
+        # Do local imports because of these incestuous self references
+        from typing import Union
+        from typing import List
+        from ogl.OglClass import OglClass
+        from ogl.OglNote import OglNote
+        try:
+            # self.getSourceShape().links.remove(self)
+            src: Union[OglClass, OglNote] = self.getSourceShape()
+            links: List[OglLink] = src.links
+            links.remove(self)
+        except ValueError as ve:
+            self.clsLogger.warning(f'Ignoring source removal error: {ve}')
+
+        try:
+            # self.getDestinationShape().links.remove(self)
+            dest: Union[OglClass, OglNote] = self.getDestinationShape()
+            links = dest.links
+            links.remove(self)
+        except ValueError as ee:
+            self.clsLogger.warning(f'Ignoring destination removal error: {ee}')
 
     def optimizeLine(self):
         """
         Optimize line, so that the line length is minimized
         """
         # Get elements
-        srcAnchor = self.GetSource()
-        dstAnchor = self.GetDestination()
+        srcAnchor = self.sourceAnchor
+        dstAnchor = self.destinationAnchor
 
         srcX, srcY = self._srcShape.GetPosition()
         dstX, dstY = self._destShape.GetPosition()
@@ -353,11 +402,11 @@ class OglLink(LineShape, ShapeEventHandler):
         #
         # Add it either before the destinationAnchor or the sourceAnchor
         #
-        lp: LinePoint = self.GetSource()
+        lp: LinePoint = self.sourceAnchor
         self.AddControl(control=cp, after=lp)
 
         frame = self._diagram.GetPanel()
-        frame.GetDiagram().AddShape(cp)
+        frame.diagram.AddShape(cp)
         frame.Refresh()
 
     def _removeBend(self, clickPoint: Tuple[int, int]):
@@ -407,8 +456,8 @@ class OglLink(LineShape, ShapeEventHandler):
 
     def __repr__(self):
 
-        srcShape: Shape = self.getSourceShape()
-        dstShape: Shape = self.getDestinationShape()
+        srcShape: Shape = self.sourceShape
+        dstShape: Shape = self.destinationShape
         sourceId: int   = srcShape.id
         dstId:    int   = dstShape.id
 
